@@ -22,7 +22,7 @@ use warnings;
 use Carp;
 use IO::File ;
 
-our $VERSION = '0.802';
+our $VERSION = '0.901';
 
 require XSLoader;
 XSLoader::load('Config::Augeas', $VERSION);
@@ -341,8 +341,19 @@ sub move {
 
 =head2 span ( path )
 
-Returns a hash containing the filename, label_start, label_end,
-value_start, value_end, span_start and span_end of the given C<path>.
+Returns a hash containing the C<filename>, C<label_start>, C<label_end>,
+C<value_start>, C<value_end>, C<span_start> and C<span_end> of the given C<path>.
+
+Example:
+
+  my $span = $aug->span('/files/etc/passwd/root') ;
+  # If filename is undefined, there are no valid span information for this node
+  if ($span->{filename}) {
+     print "Found root in passwd at character $span->{span_start}\n" ;
+  }
+
+WARNING: You must check that $span->{filename} is defined. If it isn't,
+the node has no span information and all other values in the hash are wrong.
 
 =cut
 
@@ -489,6 +500,50 @@ sub print {
     return $ret == 0 ? 1 : 0 ;
 }
 
+=head2 srun ( [ text  , [ file ] ] )
+
+Run one or more newline-separated commands listed in C<text>.
+Running just ‘help’ will print what commands are available.
+Commands accepted by this are identical to what augtool accepts.
+
+The second parameter can be :
+
+=over
+
+=item *
+
+A file name. 
+
+=item *
+
+Omitted. In this case, print to STDOUT
+
+=back
+
+The function returns the number of executed commands on success,
+and 0 otherwise.
+
+=cut
+
+sub srun {
+    my $self   = shift ;
+    my $text   = shift || '' ;
+    my $f_param     = shift ;
+
+    my $fd = IO::File->new ;
+
+    if (defined $f_param) {
+	$fd->open($f_param,"w");
+    }
+    else {
+	# stdio 
+	$fd->fdopen(fileno(STDOUT),"w");
+    } 
+
+    my $ret = $self->{aug_c} -> srun($fd,$text) ;
+    return $ret > 0 ? $ret : 0 ;
+}
+
 =head1 Error reporting
 
 =head2 error
